@@ -2,7 +2,7 @@ package Message::Passing::Collectd;
 use strict;
 use warnings;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 1;
 
@@ -14,7 +14,8 @@ Message::Passing::Collectd - a suite of adaptors between Message::Passing and co
 
 This package is a placeholder for adaptors between L<Message::Passing> and L<collectd|http://collectd.org>.
 
-Please see L<Collectd::Plugin::Write::Message::Passing>
+Please see L<Collectd::Plugin::Write::Message::Passing> (known working) and
+L<Collectd::Plugin::Read::Message::Passing> (sketch currently).
 
 =head1 AUTHOR
 
